<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>إعادة إنتاج</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>تمتد</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>فقط على %1</translation>
    </message>
</context>
</TS>